<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="zh_CN">
<context>
    <name>LXQtTaskBar</name>
    <message>
        <location filename="../../../lxqttaskbar.cpp" line="644"/>
        <source>Activate task %1</source>
        <translation>激活任务 %1</translation>
    </message>
</context>
<context>
    <name>LXQtTaskButton</name>
    <message>
        <location filename="../../../lxqttaskbutton.cpp" line="514"/>
        <source>Application</source>
        <translation>应用程序</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbutton.cpp" line="548"/>
        <source>To &amp;Desktop</source>
        <translation>转到桌面(&amp;D)</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbutton.cpp" line="550"/>
        <source>&amp;All Desktops</source>
        <translation>全部桌面(&amp;A)</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbutton.cpp" line="558"/>
        <source>Desktop &amp;%1</source>
        <translation>桌面 &amp;%1</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbutton.cpp" line="565"/>
        <source>&amp;To Current Desktop</source>
        <translation>转到当前桌面(&amp;T)</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbutton.cpp" line="573"/>
        <source>&amp;Move</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbutton.cpp" line="576"/>
        <source>Resi&amp;ze</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbutton.cpp" line="583"/>
        <source>Ma&amp;ximize</source>
        <translation>最大化(&amp;X)</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbutton.cpp" line="590"/>
        <source>Maximize vertically</source>
        <translation>垂直最大化</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbutton.cpp" line="595"/>
        <source>Maximize horizontally</source>
        <translation>水平最大化</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbutton.cpp" line="601"/>
        <source>&amp;Restore</source>
        <translation>恢复(&amp;R)</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbutton.cpp" line="605"/>
        <source>Mi&amp;nimize</source>
        <translation>最小化(&amp;N)</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbutton.cpp" line="611"/>
        <source>Roll down</source>
        <translation>卷下</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbutton.cpp" line="617"/>
        <source>Roll up</source>
        <translation>卷上</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbutton.cpp" line="625"/>
        <source>&amp;Layer</source>
        <translation>层(&amp;L)</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbutton.cpp" line="627"/>
        <source>Always on &amp;top</source>
        <translation>总在顶层(&amp;T)</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbutton.cpp" line="633"/>
        <source>&amp;Normal</source>
        <translation>正常(&amp;N)</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbutton.cpp" line="639"/>
        <source>Always on &amp;bottom</source>
        <translation>总在底层(&amp;B)</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbutton.cpp" line="647"/>
        <source>&amp;Close</source>
        <translation>关闭(&amp;C)</translation>
    </message>
</context>
<context>
    <name>LXQtTaskGroup</name>
    <message>
        <location filename="../../../lxqttaskgroup.cpp" line="83"/>
        <source>Group</source>
        <translation>组</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskgroup.cpp" line="85"/>
        <source>Close group</source>
        <translation>关闭组</translation>
    </message>
</context>
<context>
    <name>LXQtTaskbarConfiguration</name>
    <message>
        <source>LXQt Task Manager Settings</source>
        <translation type="vanished">LXQt任务管理器设置</translation>
    </message>
    <message>
        <source>Window List Content</source>
        <translation type="vanished">窗口列表内容</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbarconfiguration.ui" line="14"/>
        <source>Task Manager Settings</source>
        <translation>任务管理器设置</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbarconfiguration.ui" line="20"/>
        <source>General</source>
        <translation>常规</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbarconfiguration.ui" line="43"/>
        <source>Show only windows from desktop</source>
        <translation>只显示此桌面上的窗口</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbarconfiguration.ui" line="55"/>
        <source>Show only windows from &amp;panel&apos;s screen</source>
        <translation>只显示面板屏幕上的窗口(&amp;P)</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbarconfiguration.ui" line="62"/>
        <source>Show only minimized windows</source>
        <translation>只显示最小化的窗口</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbarconfiguration.ui" line="69"/>
        <source>Raise minimized windows on current desktop</source>
        <translation>提升当前桌面的最小化窗口</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbarconfiguration.ui" line="83"/>
        <source>Cycle windows on wheel scrolling</source>
        <translation>转动鼠标滚轮切换窗口</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbarconfiguration.ui" line="93"/>
        <source>Window &amp;grouping</source>
        <translation>窗口分组(&amp;G)</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbarconfiguration.ui" line="102"/>
        <source>Show popup on mouse hover</source>
        <translation>鼠标移过弹出菜单</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbarconfiguration.ui" line="112"/>
        <source>Appearance</source>
        <translation>外观</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbarconfiguration.ui" line="131"/>
        <source>Maximum button width</source>
        <translation>最大按钮宽度</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbarconfiguration.ui" line="144"/>
        <location filename="../../../lxqttaskbarconfiguration.ui" line="170"/>
        <source> px</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbarconfiguration.ui" line="157"/>
        <source>Maximum button height</source>
        <translation>最大按钮高度</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbarconfiguration.ui" line="190"/>
        <source>Use icons by WindowClass, if available</source>
        <translation>如果可用，使用 WindowClass 提供的图标</translation>
    </message>
    <message>
        <source>Show windows from current desktop</source>
        <translation type="vanished">显示当前桌面的窗口</translation>
    </message>
    <message>
        <source>Show windows from all desktops</source>
        <translation type="vanished">显示所有桌面的窗口</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbarconfiguration.ui" line="183"/>
        <source>Auto&amp;rotate buttons when the panel is vertical</source>
        <translation>纵置面板时自动旋转按钮(&amp;R)</translation>
    </message>
    <message>
        <source>Window List Appearance</source>
        <translation type="vanished">窗口列表外观</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbarconfiguration.ui" line="121"/>
        <source>Button style</source>
        <translation>按钮样式</translation>
    </message>
    <message>
        <source>Max button width</source>
        <translation type="vanished">最大按钮宽度</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbarconfiguration.ui" line="76"/>
        <source>Close on middle-click</source>
        <translation>鼠标中击时关闭</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbarconfiguration.cpp" line="45"/>
        <source>Icon and text</source>
        <translation>图标和文字</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbarconfiguration.cpp" line="46"/>
        <source>Only icon</source>
        <translation>仅图标</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbarconfiguration.cpp" line="47"/>
        <source>Only text</source>
        <translation>仅文字</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbarconfiguration.cpp" line="49"/>
        <source>Current</source>
        <translation>当前桌面</translation>
    </message>
</context>
</TS>
